@@ -3,7 +3,7 @@ export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bi
 echo 'name: yesod-default
 version: 1.2.0
 id: yesod-default-1.2.0-5d724e6255914e391bee90b30a4cef13
-key: yesod_3V4MmARAYlIDcHTsNweQL1
+key: yesod_K2g0rHJYdBaKvGpZhJzQXq
 license: MIT
 maintainer: Patrick Brisbin <pbrisbin@gmail.com>
 stability: Stable
@@ -21,10 +21,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-default-1.2.0
-hs-libraries: HSyesod-default-1.2.0-3V4MmARAYlIDcHTsNweQL1
+hs-libraries: HSyesod-default-1.2.0-K2g0rHJYdBaKvGpZhJzQXq
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    yesod-core-1.4.19-1b35f3e0bc5edf244c8b12abed4fd6c1
+    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
 haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
 haddock-html: /usr/share/doc/haskell-yesod-default/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
